@@ -1,6 +1,4 @@
-;; rail-table-mule.el
-
-(defvar rail-mule-codename-alist
+(defvar rail-mule-version-alist
   '(("KIRITSUBO"      . "$B6MTd(B")
     ("HAHAKIGI"       . "$BVdLZ(B")
     ("UTSUSEMI"       . "$B6u@f(B")
